#version 120

//-----------------------------
//ONLY BLOOM Shaderpack byMrY
//https://youtube.com/hdjellybeanlp
//
//Edited BLOOM CODE by krischan (original: http://wp.applesandoranges.eu/?p=14)
//
//You can use my code for what ever you want,
//but don't forget to give credits! :)
//-----------------------------

//-----adjustable-variable------------

//enable HSV_BLOOM to get a more realistic bloom

//#define HSV_BLOOM
float BLOOM_STRENGTH = 0.17; //higher value means more bloom

//-----end-of-adjustable-variable-----

varying vec4 texcoord;
uniform sampler2D bgl_RenderedTexture;

// by Sam Hocevar
vec3 rgb2hsv(vec3 c) {
    vec4 K = vec4(0.0, -1.0 / 3.0, 2.0 / 3.0, -1.0);
    vec4 p = mix(vec4(c.bg, K.wz), vec4(c.gb, K.xy), step(c.b, c.g));
    vec4 q = mix(vec4(p.xyw, c.r), vec4(c.r, p.yzx), step(p.x, c.r));
    float d = q.x - min(q.w, q.y);
    float e = 1.0e-10;
    return vec3(abs(q.z + (q.w - q.y) / (6.0 * d + e)), d / (q.x + e), q.x);
}
vec3 hsv2rgb(vec3 c) {
    vec4 K = vec4(1.0, 2.0 / 3.0, 1.0 / 3.0, 3.0);
    vec3 p = abs(fract(c.xxx + K.xyz) * 6.0 - K.www);
    return c.z * mix(K.xxx, clamp(p - K.xxx, 0.0, 1.0), c.y);
}

void main(){
	
	vec4 sum = vec4(0);
	vec2 texcoord = vec2(gl_TexCoord[0]);
	vec3 color = texture2D(bgl_RenderedTexture, texcoord.xy).rgb;
	
	int j;
	int i;

	for(i= -4 ;i < 4; i++){
        for (j = -4; j < 4; j++){
			vec2 coord = texcoord.st + vec2(j,i) * 0.004;
			if(coord.x > 0 && coord.x < 1 && coord.y > 0 && coord.y < 1){
				sum += texture2D(bgl_RenderedTexture, coord) * BLOOM_STRENGTH;
			}
        }
    }
	
	#ifdef HSV_BLOOM
		vec3 hsvColor = rgb2hsv(color);
	
		if(hsvColor.z > 0.8){
			gl_FragColor = sum*sum*0.015 + texture2D(bgl_RenderedTexture, texcoord);
		}else{
			gl_FragColor = sum*sum*0.008 + texture2D(bgl_RenderedTexture, texcoord);
		}
	#else
		if (color.r < 0.3){		//if the red-amount is less than 0.3
			gl_FragColor = sum*sum*0.014 + texture2D(bgl_RenderedTexture, texcoord);
		}else if(color.r < 0.5){
			gl_FragColor = sum*sum*0.010 + texture2D(bgl_RenderedTexture, texcoord);
		}else{
			gl_FragColor = sum*sum*0.007 + texture2D(bgl_RenderedTexture, texcoord);
		}
	#endif
}